@@ -9,7 +9,7 @@ import argparse
 import subprocess
 
 
-__VERSION__ = '0.0.7'
+__VERSION__ = '0.1.0'
 
 
 def cmd(string, cwd=os.getcwd(), verbose=True, shell=False):
@@ -21,7 +21,10 @@ def cmd(string, cwd=os.getcwd(), verbose=True, shell=False):
     process = subprocess.Popen(string, cwd=cwd, stdout=subprocess.PIPE, shell=shell)
     to_string = process.communicate()[0].decode('utf-8')
     if verbose:
-        print(to_string)
+        try:
+            print(to_string)
+        except BrokenPipeError:
+            pass
     return to_string
 
 
@@ -71,6 +74,13 @@ def add_subtree_to_json(subtree):
         file.write(json.dumps(chainsaw_json, sort_keys=True, indent=4, separators=(',', ': ')))
 
 
+def overwrite_subtree_json(subtrees):
+    """Completely overwrite existing chainsaw.json file"""
+
+    with open('chainsaw.json', 'w') as file:
+        file.write(json.dumps(subtrees, sort_keys=True, indent=4, separators=(',', ': ')))
+
+
 def add(args):
     """Add subtree and update chainsaw.json"""
 
@@ -168,10 +178,10 @@ def remove(args):
     subtrees = load_json()
     fsubtrees = filter_subtrees(all_prefixes(subtrees) if args.all else args.prefixes, subtrees)
 
-    for subt in subtrees:
+    for subt in fsubtrees:
         cmd('git rm -rf {}'.format(subt['prefix']))
 
-    add_subtree_to_json(filter_subtrees(all_prefixes(fsubtrees), subtrees, invert=True))
+    overwrite_subtree_json(filter_subtrees(all_prefixes(fsubtrees), subtrees, invert=True))
 
 
 def ls(args):
